@@ -168,11 +168,7 @@ def verify_remove_route(route):
     routes_list.remove
     
 def main(args=None):
-    if args is None:
-        args = sys.argv[1:]
-    else:
-        options_command(args)
-    print("if you don't recognize the parameter you can use 'colubrid -h'")
+    options_command(args)
 
 if __name__ == "__main__":
     sys.exit(main())
